@@ -2,7 +2,7 @@
 #
 #       License: BSD
 #       Created: September 01, 2010
-#       Author:  Francesc Alted - francesc@blosc.io
+#       Author:  Francesc Alted - francesc@blosc.org
 #
 ########################################################################
 
@@ -183,9 +183,15 @@ class ctable(object):
         self._cparams = kwargs.get('cparams', bcolz.cparams())
         self.rootdir = kwargs.get('rootdir', None)
         if self.rootdir is not None:
-            self.auto_flush = kwargs.get('auto_flush', True)
+            self.auto_flush = kwargs.pop('auto_flush', True)
         else:
             self.auto_flush = False
+            # We actually need to pop it from the kwargs, so it doesn't get
+            # passed down to the carray.
+            try:
+                kwargs.pop('auto_flush')
+            except KeyError:
+                pass
         "The directory where this object is saved."
         if self.rootdir is None and columns is None:
             raise ValueError(
@@ -196,7 +202,9 @@ class ctable(object):
             self.mode = kwargs.setdefault('mode', 'a')
             if columns is not None and self.mode == 'a':
                 raise ValueError(
-                    "You cannot pass a `columns` param in 'a'ppend mode")
+                    "You cannot pass a `columns` param in 'a'ppend mode.\n"
+                    "(If you are trying to create a new ctable, perhaps the "
+                    "directory exists already.)")
         else:
             self.mode = kwargs.setdefault('mode', 'w')
 
@@ -1246,6 +1254,11 @@ class ctable(object):
         fullrepr = header + str(self)
         return fullrepr
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, tb):
+        self.flush()
 
 # Local Variables:
 # mode: python
