@@ -3,7 +3,7 @@
 #
 #       License: BSD
 #       Created: August 5, 2010
-#       Author:  Francesc Alted - francesc@blosc.io
+#       Author:  Francesc Alted - francesc@blosc.org
 #
 ########################################################################
 
@@ -14,6 +14,7 @@ import sys
 import struct
 import shutil
 import textwrap
+from bcolz.utils import to_ndarray
 
 import numpy as np
 from numpy.testing import assert_array_equal, assert_allclose
@@ -26,12 +27,57 @@ from bcolz.carray_ext import chunk
 from bcolz import carray
 import pickle
 
+
+import ctypes
+
 is_64bit = (struct.calcsize("P") == 8)
 
 if sys.version_info >= (3, 0):
     long = int
 
 
+class initTest(TestCase):
+
+    def test_roundtrip_from_transpose1(self):
+        """Testing `__init__` called without `dtype` and a non-contiguous (transposed) array."""
+        transposed_array = np.array([[0, 1, 2], [2, 1, 0]]).T
+        assert_array_equal(transposed_array, carray(transposed_array, dtype=None))
+
+    def test_roundtrip_from_transpose2(self):
+        """Testing `__init__` called with `dtype` and a non-contiguous (transposed) array."""
+        transposed_array = np.array([[0, 1, 2], [2, 1, 0]]).T
+        assert_array_equal(transposed_array, carray(transposed_array, dtype=transposed_array.dtype))
+
+    @unittest.skipIf(not bcolz.pandas_here, "cannot import pandas")
+    def test_roundtrip_from_dataframe1(self):
+        """Testing `__init__` called without `dtype` and a dataframe over non-contiguous data."""
+        import pandas as pd
+        df = pd.DataFrame(data={
+            'a': np.arange(3),
+            'b': np.arange(3)[::-1]
+        })
+        assert_array_equal(df, carray(df, dtype=None))
+
+    @unittest.skipIf(not bcolz.pandas_here, "cannot import pandas")
+    def test_roundtrip_from_dataframe2(self):
+        """Testing `__init__` called with `dtype` and a dataframe over non-contiguous data."""
+        import pandas as pd
+        df = pd.DataFrame(data={
+            'a': np.arange(3),
+            'b': np.arange(3)[::-1]
+        })
+        ca = carray(df, dtype=np.dtype(np.float))
+        assert_array_equal(df, ca)
+        self.assertEqual(ca.dtype, np.dtype(np.float),
+                         msg='carray has been created with invalid dtype')
+
+    def test_dtype_None(self):
+        """Testing `utils.to_ndarray` called without `dtype` and a non-contiguous (transposed) array."""
+        array = np.array([[0, 1, 2], [2, 1, 0]]).T
+        self.assertTrue(to_ndarray(array, None, safe=True).flags.contiguous,
+                        msg='to_ndarray: Non contiguous arrays are not being consolidated when dtype is None')
+
+
 class chunkTest(TestCase):
 
     def test01(self):
@@ -63,19 +109,32 @@ class chunkTest(TestCase):
         assert_array_equal(a[1:8000], b[1:8000], "Arrays are not equal")
 
 
-class pickleTest(MayBeDiskTest, TestCase):
-    disk=True
+class pickleTest(MayBeDiskTest):
+
+    disk = False
+
+    def generate_data(self):
+        return bcolz.arange(1e2)
+
     def test_pickleable(self):
-        a = np.arange(1e2)
-        b = bcolz.carray(a, rootdir=self.rootdir)
+        b = self.generate_data()
         s = pickle.dumps(b)
         if PY2:
-            self.assertTrue(type(s), str)
+            self.assertIsInstance(s, str)
         else:
-            self.assertTrue(type(s), bytes)
+            self.assertIsInstance(s, bytes)
+        if self.disk:
+            b2 = pickle.loads(s)
+            # this should probably be self.assertEquals(b, b2)
+            # but at the time == didn't work
+            self.assertEquals(b2.rootdir, b.rootdir)
 
-        b2 = pickle.loads(s)
-        self.assertEquals(b2.rootdir, b.rootdir)
+
+class pickleTestDisk(pickleTest):
+    disk = True
+
+    def generate_data(self):
+        return bcolz.arange(1e2, rootdir=self.rootdir)
 
 
 class getitemTest(MayBeDiskTest):
@@ -2147,6 +2206,137 @@ class reprDiskTest(MayBeDiskTest,TestCase):
         expected = self._create_expected('a')
         self.assertEqual(expected, repr(y))
 
+class chunksIterTest(MayBeDiskTest):
+    def test00(self):
+        """Testing chunk iterator"""
+        _dtype = 'int64'
+        chunklen_ = 10
+        N = 1e2 + 3
+        a = np.arange(N, dtype=_dtype)
+        b = bcolz.carray(a, dtype=_dtype, chunklen=chunklen_,
+                         rootdir=self.rootdir)
+        # print 'nchunks', b.nchunks
+        for n, chunk_ in enumerate(b.chunks):
+            # print 'chunk nr.', n, '-->', chunk_
+            assert_array_equal(chunk_[0:chunklen_],
+                               a[n * chunklen_:(n + 1) * chunklen_],
+                               "iter chunks not working correctly")
+
+        self.assertEquals(n, len(a) // chunklen_ - 1)
+
+
+class chunksIterMemoryTest(chunksIterTest, TestCase):
+    disk = False
+
+
+class chunksIterDiskTest(chunksIterTest, TestCase):
+    disk = True
+
+class ContextManagerTest(MayBeDiskTest, TestCase):
+    disk = True
+
+    def test_with_statement_flushes(self):
+
+        with carray([], rootdir=self.rootdir, mode='w') as x:
+            x.append(1)
+        received = np.array(carray(rootdir=self.rootdir))
+        expected = np.array([1])
+        assert_array_equal(expected, received)
+
+class nleftoversTest(TestCase):
+
+    def test_empty(self):
+        a = carray([])
+        self.assertEquals(0, a.nleftover)
+
+    def test_one(self):
+        a = carray([1])
+        self.assertEqual(1, a.nleftover)
+
+    def test_beyond_one(self):
+        a = carray(np.zeros(2049), chunklen=2048)
+        self.assertEqual(1, a.nleftover)
+
+
+class LeftoverTest(MayBeDiskTest):
+
+    def test_leftover_ptr(self):
+        typesize = 8
+        items = 7
+        a = carray([i for i in range(items)], dtype='i8', rootdir=self.rootdir)
+        for i in range(items):
+            out = ctypes.c_int64.from_address(a.leftover_ptr + (i * typesize))
+            self.assertEqual(i, out.value)
+
+    def test_leftover_ptr_after_chunks(self):
+        typesize = 4
+        items = 108
+        chunklen = 100
+        a = carray([i for i in range(items)], chunklen=chunklen, dtype='i4',
+                   rootdir=self.rootdir)
+        for i in range(items % chunklen):
+            out = ctypes.c_int32.from_address(a.leftover_ptr + (i * typesize))
+            self.assertEqual(chunklen + i, out.value)
+
+    def test_leftover_array(self):
+        items = 7
+        a = carray([i for i in range(items)], dtype='i4', rootdir=self.rootdir)
+        reference = np.array([0, 1, 2, 3, 4, 5, 6], dtype='int32')
+        out = a.leftover_array[:items]
+        assert_array_equal(reference, out)
+
+    def test_leftover_bytes(self):
+        typesize = 8
+        items = 9
+        a = carray([i for i in range(items)], dtype='i8', rootdir=self.rootdir)
+        self.assertEqual(a.leftover_bytes, items * typesize)
+
+    def test_leftover_elements(self):
+        items = 9
+        a = carray([i for i in range(items)], dtype='i8', rootdir=self.rootdir)
+        self.assertEqual(a.leftover_elements, items)
+
+
+class LeftoverMemoryTest(LeftoverTest, TestCase):
+    disk = False
+
+
+class LeftoverDiskTest(LeftoverTest, TestCase):
+    disk = True
+
+    def test_leftover_ptr_create_flush_open(self):
+        typesize = 8
+        items = 120
+        chunklen = 50
+        n_leftovers = items % chunklen
+        n_chunks = items // chunklen
+
+        a = carray([i for i in range(items)], chunklen=chunklen, dtype='i8',
+                   rootdir=self.rootdir)
+        a.flush()
+
+        b = carray(rootdir=self.rootdir)
+        for i in range(n_leftovers):
+            out = ctypes.c_int32.from_address(b.leftover_ptr + (i * typesize))
+            self.assertEqual((n_chunks * chunklen) + i, out.value)
+
+    def test_leftover_ptr_with_statement_create_open(self):
+        typesize = 8
+        items = 120
+        chunklen = 50
+        n_leftovers = items % chunklen
+        n_chunks = items // chunklen
+
+        ca = carray([], chunklen=chunklen, dtype='i8', rootdir=self.rootdir)
+        with ca as a:
+            for i in range(items):
+                a.append(i)
+
+        b = carray(rootdir=self.rootdir)
+        for i in range(n_leftovers):
+            out = ctypes.c_int32.from_address(b.leftover_ptr + (i * typesize))
+            self.assertEqual((n_chunks * chunklen) + i, out.value)
+
 
 if __name__ == '__main__':
     unittest.main(verbosity=2)
