@@ -2,7 +2,7 @@
 #
 #       License: BSD
 #       Created: September 1, 2010
-#       Author:  Francesc Alted - francesc@blosc.io
+#       Author:  Francesc Alted - francesc@blosc.org
 #
 ########################################################################
 
@@ -1973,6 +1973,19 @@ class pickleTest(MayBeDiskTest, TestCase):
         self.assertEquals(b2.rootdir, b.rootdir)
         self.assertEquals(type(b2), type(b))
 
+    def test_pickleable_memory(self):
+        b = bcolz.ctable([[1, 2, 3], [1, 2, 3]],
+                         names=['a', 'b'],
+                         rootdir=None)
+        s = pickle.dumps(b)
+        if PY2:
+            self.assertIsInstance(s, str)
+        else:
+            self.assertIsInstance(s, bytes)
+
+        b2 = pickle.loads(s)
+        self.assertEquals(type(b2), type(b))
+
 
 class FlushDiskTest(MayBeDiskTest, TestCase):
     disk = True
@@ -2091,6 +2104,46 @@ class FlushDiskTest(MayBeDiskTest, TestCase):
         self.assertTrue(len(t) == 1)
         self.assertTrue(t["a"][0] == b"aaaaa", t["a"][0])
 
+    def test_auto_flush_constructor_keyword_true_memory(self):
+        t = bcolz.ctable([np.empty(0, dtype='i8')], auto_flush=True)
+        #self.assertTrue(t.auto_flush)
+        # attribute will be False, since it is always false for MemCarray.
+        self.assertFalse(t.auto_flush)
+
+    def test_auto_flush_constructor_keyword_true_disk(self):
+        t = bcolz.ctable([np.empty(0, dtype='i8')],
+                         rootdir=self.rootdir, auto_flush=True)
+        self.assertTrue(t.auto_flush)
+
+    def test_auto_flush_constructor_keyword_false_memory(self):
+        t = bcolz.ctable([np.empty(0, dtype='i8')], auto_flush=False)
+        self.assertFalse(t.auto_flush)
+
+    def test_auto_flush_constructor_keyword_false_disk(self):
+        t = bcolz.ctable([np.empty(0, dtype='i8')],
+                         rootdir=self.rootdir, auto_flush=False)
+        self.assertFalse(t.auto_flush)
+
+
+class ContextManagerTest(MayBeDiskTest, TestCase):
+    disk = True
+
+    def test_with_statement_flushes(self):
+
+        with bcolz.ctable(np.empty(0, dtype="S2,i4,i8,f8"),
+                          rootdir=self.rootdir, mode="w") as x:
+            x.append(("a", 1, 2, 3.0))
+            x.append(("b", 4, 5, 6.0))
+
+        received = bcolz.ctable(rootdir=self.rootdir)[:]
+        expected = \
+            np.array([('a', 1, 2, 3.0), ('b', 4, 5, 6.0)],
+                     dtype=[('f0', 'S2'), ('f1', '<i4'),
+                            ('f2', '<i8'), ('f3', '<f8')])
+
+        assert_array_equal(expected, received)
+
+
 if __name__ == '__main__':
     unittest.main(verbosity=2)
 
